@@ -1,5 +1,6 @@
 library(circlize)
 set.seed(12345)
+op = par(no.readonly = FALSE)
 par(mar = c(1, 1, 1, 1))
 factors = letters[1:4]
 circos.par("canvas.xlim" = c(-1.5, 1.5), "canvas.ylim" = c(-1.5, 1.5), "gap.degree" = 10)
@@ -16,4 +17,5 @@ circos.trackPlotRegion(ylim = c(0, 1), panel.fun = function(x, y) {
 
 text(0, 0, "this is\nthe center", cex = 1.5)
 legend("bottomleft", pch = 1, legend = "this is the legend")
-circos.clear()
\ No newline at end of file
+circos.clear()
+par(op)
